@@ -295,16 +295,72 @@ static void draw_lines(struct graphics_priv *gra, struct graphics_gc_priv *gc, s
     (*jnienv)->DeleteLocalRef(jnienv, points);
 }
 
+/* calculate the area a polygon covers in pixels.
+ *
+ * Bonus: Positive area indicates clockwise, negative counter clockwise
+ */
+static int polygon_area(struct point* p, int count) {
+    int area =0;
+    int i;
+
+    /* initialize j with the last point */
+    int j = count -1;
+
+    for(i=0; i < count; i ++) {
+        area += (p[j].x + p[i].x) * (p[j].y - p[i].y);
+        j = i; /* j is previous vertex to i */
+    }
+    return area/2;
+}
+
+/* returns if vertexes of given polygon are clockwise
+ *
+ * @returns: > o if clockwise, otherwise counter clockwise.
+ *
+ * Note: On self intersecting polygons, it will return if it is
+ * "mostly" clockwise. Be warned.
+ */
+static inline int is_clockwise (struct point * p, int count) {
+    return polygon_area(p, count);
+}
+
+/* copy over vertexes to the jni array. Allows to reverse the polygon */
+static int add_vertex_to_java_array(struct point * p, int count, jint * j_p, int reverse) {
+    int i;
+    if(reverse > 0) {
+        for(i=0; i < count; i ++) {
+            j_p[i*2]=p[(count -1) -i].x;
+            j_p[i*2+1]=p[(count -1) -i].y;
+        }
+    } else {
+        for(i=0; i < count; i ++) {
+            j_p[i*2]=p[i].x;
+            j_p[i*2+1]=p[i].y;
+        }
+    }
+    return count * 2;
+}
+
+/* prepare the java call to draw a polygon with holes. As Java drawing code assumes polygons are directed
+ * clockwise for outer and counter clockwise for inner, all polygons are checked and reversed if required.
+ * While the reversing does not add significant overhead, the calculating adds some overhead.
+ *
+ * TODO: Find a more performant way of doing this probably NOT requiring the java code to get the polygons
+ * directd.
+ */
 static void draw_polygon_with_holes (struct graphics_priv *gra, struct graphics_gc_priv *gc, struct point *p, int count,
                                      int hole_count, int* ccount, struct point **holes) {
     int i;
     /* need to get us some arrays for java */
     int java_p_size;
     jintArray java_p;
+    jint * j_p=NULL;
     int java_ccount_size;
     jintArray java_ccount;
+    jint * j_ccount=NULL;
     int java_holes_size;
     jintArray java_holes;
+    jint * j_holes=NULL;
 
     /* Don't even try to draw a polygon with less than 3 points */
     if(count < 3)
@@ -313,34 +369,33 @@ static void draw_polygon_with_holes (struct graphics_priv *gra, struct graphics_
     /* get java array for coordinates */
     java_p_size=count*2;
     java_p = (*jnienv)->NewIntArray(jnienv,java_p_size);
-    jint j_p[java_p_size];
-    for (i = 0 ; i < count ; i++) {
-        j_p[i*2]=p[i].x;
-        j_p[(i*2)+1]=p[i].y;
-    }
+    j_p = g_malloc(sizeof(jint) * java_p_size);
+
+    /* add outer polygon to java array. Ensure it's clockwise */
+    add_vertex_to_java_array(p, count, j_p, (is_clockwise(p, count) > 0)? 0: 1);
 
     /* get java array for ccount */
     java_ccount_size = hole_count;
     java_ccount=(*jnienv)->NewIntArray(jnienv,java_ccount_size);
-    jint j_ccount[java_ccount_size];
+    j_ccount=g_malloc(sizeof(jint) * java_ccount_size);
     /* get java array for hole coordinates */
     java_holes_size = 0;
     for(i=0; i < hole_count; i ++) {
         java_holes_size += ccount[i] * 2;
     }
-    java_holes=(*jnienv)->NewIntArray(jnienv,java_ccount_size);
-    /* copy over the holes to the jint array */
+    java_holes=(*jnienv)->NewIntArray(jnienv,java_holes_size);
+    j_holes=g_malloc(sizeof(jint) * java_holes_size);
+
+    /* copy over the holes to the jint coordinate array */
     int j_holes_used=0;
-    jint j_holes[java_holes_size];
     for(i=0; i < hole_count; i ++) {
-        int j;
+        /* remember this holes ccount */
         j_ccount[i] = ccount[i] * 2;
-        for(j=0; j<ccount[i]; j ++) {
-            j_holes[j_holes_used + (j * 2)] = holes[i][j].x;
-            j_holes[j_holes_used + (j * 2) +1] = holes[i][j].y;
-        }
-        j_holes_used += j_ccount[i];
+        /* add inner polygon. ensure its counter clockwise */
+        j_holes_used += add_vertex_to_java_array(holes[i], ccount[i], &(j_holes[j_holes_used]), (is_clockwise(holes[i],
+                        ccount[i]) <= 0)? 0: 1);
     }
+
     /* attach the arrays with their storage to the JVM */
     (*jnienv)->SetIntArrayRegion(jnienv, java_p, 0, java_p_size, j_p);
     (*jnienv)->SetIntArrayRegion(jnienv, java_ccount, 0, java_ccount_size, j_ccount);
@@ -352,6 +407,9 @@ static void draw_polygon_with_holes (struct graphics_priv *gra, struct graphics_
     (*jnienv)->DeleteLocalRef(jnienv, java_holes);
     (*jnienv)->DeleteLocalRef(jnienv, java_ccount);
     (*jnienv)->DeleteLocalRef(jnienv, java_p);
+    g_free(j_p);
+    g_free(j_ccount);
+    g_free(j_holes);
 }
 
 static void draw_polygon(struct graphics_priv *gra, struct graphics_gc_priv *gc, struct point *p, int count) {
@@ -873,7 +931,7 @@ static struct graphics_priv *graphics_android_new(struct navit *nav, struct grap
     ret->padding->right = 0;
     ret->padding->bottom = 0;
     /* attr_background_color is the background color for system bars (API 17+ only) */
-    if ((attr=attr_search(attrs, NULL, attr_background_color))) {
+    if ((attr=attr_search(attrs, attr_background_color))) {
         ret->bgcolor = (attr->u.color->a / 0x101) << 24
                        | (attr->u.color->r / 0x101) << 16
                        | (attr->u.color->g / 0x101) << 8
@@ -884,10 +942,10 @@ static struct graphics_priv *graphics_android_new(struct navit *nav, struct grap
         /* default is the same as for OSD */
         ret->bgcolor = 0xa0000000;
     }
-    if ((attr=attr_search(attrs, NULL, attr_use_camera))) {
+    if ((attr=attr_search(attrs, attr_use_camera))) {
         use_camera=attr->u.num;
     }
-    if ((attr=attr_search(attrs, NULL, attr_callback_list))) {
+    if ((attr=attr_search(attrs, attr_callback_list))) {
         command_add_table(attr->u.callback_list, commands, sizeof(commands)/sizeof(struct command_table), ret);
     }
     image_cache_hash = g_hash_table_new(g_str_hash, g_str_equal);
