@@ -940,7 +940,7 @@ static struct map_priv *map_route_occluded_new(struct map_methods *meth, struct
     struct map_priv *ret;
     struct attr *navit;
     dbg(lvl_debug, "enter\n");
-    navit = attr_search(attrs, NULL, attr_navit);
+    navit = attr_search(attrs, attr_navit);
     if (!navit) {
         return NULL;
     }
@@ -1338,7 +1338,7 @@ static void pedestrian_navit_init(struct navit *nav) {
 #endif
     transform_set_scale(trans, 16);
     navit_get_attr(nav, attr_layout, &initial_layout, NULL);
-    iter = navit_attr_iter_new();
+    iter = navit_attr_iter_new(NULL);
     while (navit_get_attr(nav, attr_layout, &attr, iter)) {
         if (!strcmp(attr.u.layout->name, "Route")) {
             dbg(lvl_debug, "found %s", attr_to_name(attr.type));
@@ -1397,7 +1397,7 @@ void plugin_init(void) {
     callback.type = attr_callback;
     callback.u.callback = callback_new_attr_0(callback_cast(pedestrian_navit), attr_navit);
     config_add_attr(config, &callback);
-    iter = config_attr_iter_new();
+    iter = config_attr_iter_new(NULL);
     while (config_get_attr(config, attr_navit, &navit, iter)) {
         pedestrian_navit_init(navit.u.navit);
     }
